<?php

include_once "d2p_manager.inc";

class	d2p_table
{
	var	$manager;
	var	$super;
	var	$name;
	var	$pgName;
	var	$fields;
	var	$identifier;
	var	$objects;

	// Initialize a new table representation
	function	d2p_table(&$manager, &$super, $name, $pgName)
	{
		$this->manager = $manager;
		$this->super = $super;
		$this->name = $name;
		$this->pgName = $pgName;
		if	(is_object($super) && is_a($super, "d2p_table"))
		{
			$this->fields = $super->fields;
			$this->identifier = $super->identifier;
		}
		else
		{
			$this->fields = array();
			$this->identifier = NULL;
		}
		$this->objects = array();
	}

	// Add a field to the list
	function	addField($name, $type, $mandatory = false)
	{
		if	(!is_array($this->fields[$name]))
			$this->fields[$name] = array(
				"type"		=> $type,
				"from_table"	=> $this->pgName,
				"mandatory"	=> $mandatory ? true : false
			);
	}

	// Set description for a field
	function	setFieldDescription($name, $description)
	{
		if	(is_array($this->fields[$name]))
			$this->fields[$name]["description"] = $description;
	}

	// Set the identifier field name
	function	setIdentifier($identifier)
	{
		if	($this->identifier)
			return	false;

		if	(is_array($identifier))
			$fieldlist = $identifier;
		elseif	(preg_match("/,/", $identifier))
			$fieldlist = explode(",", $identifier);
		else
			$fieldlist = array($identifier);

		foreach	($fieldlist as $fn)
		{
			if	(!is_array($this->fields[$fn]))
				return	false;
		}
		$this->identifier = $fieldlist;
		return	true;
	}

	// Notify the table that one of its rows just changed
	function	objectModified(&$object)
	{
		$this->manager->objectModifier($object);
	}


	// Get the description for a field
	function	getFieldDescription($name)
	{
		if	(is_array($this->fields[$name]))
		{
			if	(!$this->fields[$name]["description"])
				$this->fields[$name]["description"] = $name;
			return	$this->fields[$name]["description"];
		}
		return	"";
	}

	// Get the type for a field
	function	getFieldType($name)
	{
		if	(is_array($this->fields[$name]))
			return	$this->fields[$name]["type"];
		return	"";
	}

	// Returns true if the field is mandatory
	function	isFieldMandatory($name)
	{
		if	(is_array($this->fields[$name]))
			return	$this->fields[$name]["mandatory"];
		return	false;
	}

	// Get the identifier field name
	function	getIdentifier()
	{
		return	$this->identifier;
	}

	// Get an object from the cache
	function	getObject($identifierValue)
	{
		return	$this->objects[$identifierValue];
	}
}


?>
